
# Type: mappings


A list of terms from different schemas or terminology systems that have comparable meaning. These may include terms that are precisely equivalent, broader or narrower in meaning, or otherwise semantically related but not equivalent from a strict ontological perspective.

URI: [meta:mappings](https://w3id.org/biolink/biolinkml/meta/mappings)


## Domain and Range

None ->  <sub>0..*</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children

 *  [close mappings](close_mappings.md)
 *  [exact mappings](exact_mappings.md)
 *  [related mappings](related_mappings.md)

## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:mappingRelation |

